package com.codegeist.fisheye.core;

import org.eclipse.core.runtime.Plugin;
import org.osgi.framework.BundleContext;

import com.codegeist.fisheye.core.connection.IFisheyeConnectionManager;
import com.codegeist.fisheye.internal.core.connection.FisheyeConnectionManager;
import com.codegeist.fisheye.internal.core.connection.FisheyeConnectionStorage;

/**
 * The activator class controls the plug-in life cycle
 */
public class Activator extends Plugin {

	// The plug-in ID
	public static final String PLUGIN_ID = "com.codegeist.fisheye.core";

	// The shared instance
	private static Activator plugin;
	
	private FisheyeConnectionManager connectionManager;

	private FisheyeConnectionStorage connectionStorage;
	
	/**
	 * The constructor
	 */
	public Activator() {
	}

	/*
	 * (non-Javadoc)
	 * @see org.eclipse.core.runtime.Plugins#start(org.osgi.framework.BundleContext)
	 */
	public void start(BundleContext context) throws Exception {
		super.start(context);
		plugin = this;

		connectionManager = new FisheyeConnectionManager();
		
		connectionStorage = new FisheyeConnectionStorage(connectionManager, getStateLocation().toFile());
		connectionStorage.load();
	}

	/*
	 * (non-Javadoc)
	 * @see org.eclipse.core.runtime.Plugin#stop(org.osgi.framework.BundleContext)
	 */
	public void stop(BundleContext context) throws Exception {
		connectionStorage.store();
		
		plugin = null;
		super.stop(context);
	}

	/**
	 * Returns the shared instance
	 *
	 * @return the shared instance
	 */
	public static Activator getDefault() {
		return plugin;
	}
	
	/**
	 * Returns the connection manager
	 * @return Fisheye connection manager
	 */
	public IFisheyeConnectionManager getConnectionManager() {
		return connectionManager;
	}

}
