package com.codegeist.fisheye.core.connection;

import java.util.List;


/**
 * Interface for managing connections to FishEye servers.
 * 
 * @author Brock Janiczak
 * @noimplement This interface is not intended to be implemented by clients.
 */
public interface IFisheyeConnectionManager {

	/**
	 * Adds a new connection listener
	 * @param listener Connection listener
	 */
	void addConnectionListener(IConnectionListener listener);
	
	/**
	 * Removes the supplied connection listener
	 * @param listener Connection listener
	 */
	void removeConnectionListener(IConnectionListener listener);
	
	/**
	 * Retrieves an immutable list of all available connections.  The list returned is static,
	 * use {@link #addConnectionListener(IConnectionListener)} and {@link #removeConnectionListener(IConnectionListener)}
	 * to pickup changes to the list.
	 * @return immutable list of all available connections
	 */
	List<FisheyeConnection> getConnections();
	
	/**
	 * Retrieves a connection given a logical connection name
	 * @param connectionName Connection name
	 * @return COnnection details or <code>null</code> if no match was found
	 */
	FisheyeConnection getConnectionByName(String connectionName);
	
	/**
	 * Creates a new FishEye connection.  If there is already a connection with the same
	 * name, the connection URL will be updated and the new connection returned.
	 * @param name Logical name for the connection
	 * @param connectionUrl Physical location to connect to
	 * @return New connection details
	 */
	FisheyeConnection createConnection(String name, String connectionUrl);
	
	/**
	 * Removes the supplied connection.
	 * @param connection Connection to remove
	 */
	void removeConnection(FisheyeConnection connection);
}
