package com.codegeist.fisheye.internal.core.connection;

import java.io.File;
import java.util.List;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.dom.DOMSource;
import javax.xml.transform.stream.StreamResult;

import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.Status;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;

import com.codegeist.fisheye.core.Activator;
import com.codegeist.fisheye.core.connection.FisheyeConnection;
import com.codegeist.fisheye.core.connection.IFisheyeConnectionManager;

public class FisheyeConnectionStorage {
	private final IFisheyeConnectionManager manager;
	private final File stateFile;

	public FisheyeConnectionStorage(IFisheyeConnectionManager manager, File stateLocation) {
		this.manager = manager;
		this.stateFile = new File(stateLocation, "connections.xml");
	}
	
	public void load() {
		try {
			if (!stateFile.exists()) {
				if (!stateFile.createNewFile()) {
					Activator.getDefault().getLog().log(new Status(IStatus.WARNING, Activator.PLUGIN_ID, "Unable to create connection state file"));
					return;
				}
			}
			
			DocumentBuilder documentBuilder = DocumentBuilderFactory.newInstance().newDocumentBuilder();
			Document document = documentBuilder.parse(stateFile);

			Element rootElement = document.getDocumentElement();

			NodeList connections = rootElement.getElementsByTagName("connection");

			for (int i = 0; i < connections.getLength(); i++) {
				Element connection = (Element) connections.item(i);
				String connectionName = connection.getAttribute("name");
				String connectionUrl = connection.getTextContent();

				manager.createConnection(connectionName, connectionUrl);
			}
		} catch (Exception e) {
			Activator.getDefault().getLog().log(new Status(IStatus.ERROR, Activator.PLUGIN_ID, "Error loading connections", e));
		}
	}
	
	public void store() {
		try {
			if (!stateFile.exists()) {
				if (!stateFile.createNewFile()) {
					Activator.getDefault().getLog().log(new Status(IStatus.WARNING, Activator.PLUGIN_ID, "Unable to create connection state file"));
					return;
				}
			}
			DocumentBuilder documentBuilder = DocumentBuilderFactory.newInstance().newDocumentBuilder();
			Document document = documentBuilder.newDocument();
			Node connectionsNode = document.appendChild(document.createElement("connections"));
			
			List<FisheyeConnection> connections = manager.getConnections();
			for (FisheyeConnection connection : connections) {
				Element connectionElement = (Element) connectionsNode.appendChild(document.createElement("connection"));
				connectionElement.setAttribute("name", connection.getName());
				connectionElement.setTextContent(connection.getConnectionUrl());
			}
			
			Transformer transformer = TransformerFactory.newInstance().newTransformer();
			transformer.transform(new DOMSource(document), new StreamResult(stateFile));
		} catch (Exception e) {
			Activator.getDefault().getLog().log(new Status(IStatus.ERROR, Activator.PLUGIN_ID, "Error saving connections", e));
		}
	}
}
