package com.codegeist.fisheye.domain;

import static org.junit.Assert.*;

import org.junit.Test;

public class VersionTest {

	@Test
	public void testUnknownVersion() {
		Version v = Version.fromString("");
		assertEquals(Version.UNKNOWN, v);
	}
	
	@Test
	public void testMajorOnlyVersion() {
		Version v = Version.fromString("1");
		assertEquals(new Version(1, 0, 0), v);
	}
	
	@Test
	public void testMajorAndMinorVersion() {
		Version v = Version.fromString("1.2");
		assertEquals(new Version(1, 2, 0), v);
	}
	
	@Test
	public void testMajorMinorAndPatchVersion() {
		Version v = Version.fromString("1.2.3");
		assertEquals(new Version(1, 2, 3), v);
	}
	
	@Test
	public void testPatchComparison() {
		Version v1 = Version.fromString("1.2.3");
		Version v2 = Version.fromString("1.2.4");
		
		assertTrue(v1.compareTo(v2) < 0);
		assertTrue(v2.compareTo(v1) > 0);
		assertTrue(v1.compareTo(v1) == 0);
		assertTrue(v2.compareTo(v2) == 0);
	}
	
	@Test
	public void testMinorComparison() {
		Version v1 = Version.fromString("1.4.3");
		Version v2 = Version.fromString("1.2.4");
		
		assertTrue(v1.compareTo(v2) > 0);
		assertTrue(v2.compareTo(v1) < 0);
		assertTrue(v1.compareTo(v1) == 0);
		assertTrue(v2.compareTo(v2) == 0);
	}
	
	@Test
	public void testMajorComparison() {
		Version v1 = Version.fromString("3.1.0");
		Version v2 = Version.fromString("2.4.4");
		
		assertTrue(v1.compareTo(v2) > 0);
		assertTrue(v2.compareTo(v1) < 0);
		assertTrue(v1.compareTo(v1) == 0);
		assertTrue(v2.compareTo(v2) == 0);
	}
	
	@Test
	public void testMajorOnlyComparison() {
		Version v1 = Version.fromString("2");
		Version v2 = Version.fromString("1.2.4");
		
		assertTrue(v1.compareTo(v2) > 0);
		assertTrue(v2.compareTo(v1) < 0);
		assertTrue(v1.compareTo(v1) == 0);
		assertTrue(v2.compareTo(v2) == 0);
	}
	
	@Test
	public void testSimilarMajorVersionComparison() {
		Version v1 = Version.fromString("2");
		Version v2 = Version.fromString("2.0.0");
		
		assertTrue(v1.compareTo(v2) == 0);
		assertTrue(v2.compareTo(v1) == 0);
		assertTrue(v1.compareTo(v1) == 0);
		assertTrue(v2.compareTo(v2) == 0);
	}
}
