package com.codegeist.fisheye.domain;

import java.util.Date;
import java.util.HashMap;
import java.util.Map;

/**
 * <pre>
 * struct Revision {
 *  String path; // (REST: attribute)
 *  String rev; // (REST: attribute)
 *  String author; // (REST: attribute)
 *  Date date; // (REST: attribute)
 *  String state; // one of "changed" "added" or "deleted" (REST: attribute)
 *  int totalLines; // (REST: attribute)
 *  int linesAdded; // (REST: attribute)
 *  int linesRemoved; // (REST: attribute)
 *  String log;
 *  String csid; // optional (REST: attribute)
 *  String ancestor; // optional (REST: attribute)
 * }
 * </pre>
 * @author Brock Janiczak
 *
 */
public class Revision {
	public enum State {
		CHANGED, ADDED, DELETED;
	}
	
	private static final Map<String, State> stateMap = new HashMap<String, State>();
	{
		stateMap.put("changed", State.CHANGED);
		stateMap.put("added", State.ADDED);
		stateMap.put("deleted", State.DELETED);
	}
	
	private final RevisionKey key;
	private final String author;
	private final Date date;
	private final State state;
	private final int totalLines;
	private final int linesAdded;
	private final int linesRemoved;
	private final String log;
	private final String changesetId;
	private final String ancestor;
	
	
	public Revision(String path, String rev, String author, Date date, String state, int totalLines, int linesAdded, int linesRemoved, String log, String changesetId, String ancestor) {
		this.key = new RevisionKey(path, rev);
		this.author = author;
		this.date = date;
		this.state = stateMap.get(state);
		this.totalLines = totalLines;
		this.linesAdded = linesAdded;
		this.linesRemoved = linesRemoved;
		this.log = log;
		this.changesetId = changesetId;
		this.ancestor = ancestor;
	}


	public static Map<String, State> getStateMap() {
		return stateMap;
	}


	public RevisionKey getKey() {
		return key;
	}


	public String getAuthor() {
		return author;
	}


	public Date getDate() {
		return date;
	}


	public State getState() {
		return state;
	}


	public int getTotalLines() {
		return totalLines;
	}


	public int getLinesAdded() {
		return linesAdded;
	}


	public int getLinesRemoved() {
		return linesRemoved;
	}


	public String getLog() {
		return log;
	}


	public String getChangesetId() {
		return changesetId;
	}


	public String getAncestor() {
		return ancestor;
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		
		sb.append(this.key);
		sb.append(" ");
		sb.append("<").append(state).append(">");
		
		return sb.toString();
	}
}
