package com.codegeist.fisheye.internal.ui.connection.model;

import org.eclipse.core.runtime.IAdaptable;
import org.eclipse.team.ui.history.IHistoryPageSource;

import com.codegeist.fisheye.domain.PathInfo;
import com.codegeist.fisheye.internal.ui.history.FisheyeHistoryPageSource;

public class PathModel implements IAdaptable {

	private final RepositoryModel repo;
	private final PathInfo pathInfo;
	private final PathModel parent;

	public PathModel(RepositoryModel repo, PathModel parent, PathInfo pathInfo) {
		this.repo = repo;
		this.parent = parent;
		this.pathInfo = pathInfo;
	}
	
	public PathModel getParent() {
		return parent;
	}
	
	public PathInfo getPathInfo() {
		return pathInfo;
	}
	
	public RepositoryModel getRepo() {
		return repo;
	}
	
	public Object getAdapter(Class adapter) {
		if (IHistoryPageSource.class == adapter) {
			return new FisheyeHistoryPageSource();
		}
		
		return null;
	}
	
	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result
				+ ((pathInfo == null) ? 0 : pathInfo.hashCode());
		result = prime * result + ((repo == null) ? 0 : repo.hashCode());
		return result;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (getClass() != obj.getClass())
			return false;
		PathModel other = (PathModel) obj;
		if (pathInfo == null) {
			if (other.pathInfo != null)
				return false;
		} else if (!pathInfo.equals(other.pathInfo))
			return false;
		if (repo == null) {
			if (other.repo != null)
				return false;
		} else if (!repo.equals(other.repo))
			return false;
		return true;
	}

	@Override
	public String toString() {
		return pathInfo.getName();
	}
}
