package com.codegeist.fisheye.internal.ui.search;

import org.eclipse.jface.viewers.ITreeContentProvider;
import org.eclipse.jface.viewers.LabelProvider;
import org.eclipse.jface.viewers.TreeViewer;
import org.eclipse.jface.viewers.Viewer;
import org.eclipse.search.ui.ISearchResult;
import org.eclipse.search.ui.ISearchResultListener;
import org.eclipse.search.ui.ISearchResultPage;
import org.eclipse.search.ui.ISearchResultViewPart;
import org.eclipse.search.ui.SearchResultEvent;
import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.ui.IMemento;
import org.eclipse.ui.part.Page;

public class FisheyeSearchResultPage extends Page implements ISearchResultPage {
	private String id;
	private FisheyeSearchResult searchResult;
	private ISearchResultViewPart part;
	private TreeViewer resultsViewer;
	private ISearchResultListener searchListener;

	@Override
	public void createControl(Composite parent) {
		resultsViewer = new TreeViewer(parent, SWT.NONE);
		
		resultsViewer.setLabelProvider(new LabelProvider() {
			@Override
			public String getText(Object element) {
				QueryMatch match = (QueryMatch) element;
				StringBuilder sb = new StringBuilder();
				sb.append(match.getPath());
				sb.append(" ");
				sb.append(match.getRevision());
				sb.append(" (");
				sb.append("+");
				sb.append(match.getLinesAdded());
				if (!match.isNew()) {
					sb.append(" -");
					sb.append(match.getLinesRemoved());
				}
				sb.append(")");
				if (match.isNew()) {
					sb.append(" new");
				}
				return sb.toString();
			}
			
		});
		resultsViewer.setContentProvider(new ITreeContentProvider() {
		
			public void inputChanged(Viewer viewer, Object oldInput, Object newInput) {
				// TODO Auto-generated method stub
		
			}
		
			public void dispose() {
				// TODO Auto-generated method stub
		
			}
		
			public Object[] getElements(Object inputElement) {
				FisheyeSearchResult results = (FisheyeSearchResult) inputElement;
				return results.getMatches().toArray();
			}
		
			public boolean hasChildren(Object element) {
				// TODO Auto-generated method stub
				return false;
			}
		
			public Object getParent(Object element) {
				// TODO Auto-generated method stub
				return null;
			}
		
			public Object[] getChildren(Object parentElement) {
				// TODO Auto-generated method stub
				return null;
			}
		});
	}

	@Override
	public Control getControl() {
		return resultsViewer.getControl();
	}

	@Override
	public void setFocus() {
		resultsViewer.getControl().setFocus();
	}

	public String getID() {
		return id;
	}

	public String getLabel() {
		return searchResult.getLabel();
	}

	public Object getUIState() {
		// TODO Auto-generated method stub
		return null;
	}

	public void restoreState(IMemento memento) {
		// TODO Auto-generated method stub
		
	}

	public void saveState(IMemento memento) {
		// TODO Auto-generated method stub
		
	}

	public void setID(String id) {
		this.id = id;
	}

	public void setInput(ISearchResult search, Object uiState) {

		if (searchResult != null && searchListener != null) {
			searchResult.removeListener(searchListener);
			searchListener = null;
		}
		
		this.searchResult = (FisheyeSearchResult) search;
		
		if (searchResult != null) {
			searchListener = new ISearchResultListener() {
			
				public void searchResultChanged(final SearchResultEvent e) {
					getControl().getDisplay().asyncExec(new Runnable() {
					
						public void run() {
							MatchEvent event = (MatchEvent) e;
							resultsViewer.add(searchResult, event.getMatch());
						}
					});
				}
			};
			
			searchResult.addListener(searchListener);
			resultsViewer.setInput(searchResult);
		}
	}

	public void setViewPart(ISearchResultViewPart part) {
		this.part = part;
	}

}
